type Recordable<T = any> = Record<string, T>;
/**
 * 从对象中移除键值为假值的键
 * @param obj 要处理的对象
 * @returns 处理后的对象，不包含键值为假值的键
 */
export declare function removeFalsyKeys(obj: Recordable): Recordable;
/**
 * 把源对象中的值赋值到目标对象
 * @param obj1 目标对象
 * @param obj2 源对象
 * @returns 把源对象中的值赋值到目标对象
 */
export declare function copySameKeys(obj1: Recordable, obj2: Recordable): Recordable;
/**
 * 比较两个对象，并返回一个包含更新对象中更改的键和值的对象。
 *
 * @param {Object} original - 要比较的原始对象。
 * @param {Object} updated - 要比较的更新对象。
 * @returns {Object} 包含更新对象中更改的键和值的对象。
 */
export declare function compareObjects(original: Recordable, updated: Recordable): Recordable;
/**
 * 对象深拷贝函数
 * @param obj 需要拷贝的对象
 * @returns 拷贝后的新对象
 */
export declare function deepCopy<T>(obj: T): T;
/**
 * 把对象中的空值清除掉
 * @param parameters 要处理的对象
 * @returns 处理后的对象
 */
export declare function paramsHandling(parameters: Recordable): Recordable;
/**
 * 根据键的属性从 row 对象中提取该键的值
 * @param row 需要处理的对象
 * @param keys 需要设置的键
 * @returns 处理后的对象
 */
export declare function rowKeyHandling(row: Recordable, keys: string | string[]): Recordable<any>;
/**
 * 比较两个 Obj 的值是否修改
 * @param obj1 原obj
 * @param obj2 新obj
 * @returns 修改过的obj
 */
export declare function isObjEqual(obj1: any, obj2: any): any;
/**
 * 复制对象中的值
 * @param obj1 目标对象
 * @param obj2 源对象
 * @returns 返回新的对象
 */
export declare function copyObjectValues(obj1: any, obj2: any): Recordable<any>;
export {};
